#include <QApplication>
#include <QStackedWidget>
#include <QTimer>
#include <QGraphicsObject>
#include <QSettings>

/*Application includes*/
#include "sdk-connectivity-tool.h"
#include "mainwindow.h"
#include "netinterfaces.h"
#include "editinterface.h"
#include "processrunner.h"
#include "passwd.h"
#include "usbmanage.h"
#include "processmanager.h" /*vnc code*/
#include <QFile>

MainWindow::MainWindow(QApplication *parent):selectConnectionScreen(false)
{
    DIN;
    usbConnected = false;
    m_bVncViewOnly = true;
    m_sVncIp = "0.0.0.0";
    m_app = parent;
    m_runner = new ProcessRunner;
    m_userRunner =  new ProcessRunner;
    m_netinterfaces = new NetInterfaces(this, m_runner);

    m_editinterface = new EditInterface(this, m_runner);

    m_passwd = new Passwd(this);
    m_usbmanage = new UsbManage(this);
    m_vncProcess = new vncProcessManager(); /*vnc code*/

    bool value = isUsbConnected();

    if(value == true)
    {
        usbConnected = true;
    }


    /*reset password when application exits.*/
    connect(parent, SIGNAL(aboutToQuit()), m_passwd, SLOT(reset()));

    /*Usb interface is gone when module is loaded so update interfaces*/
    connect(m_usbmanage, SIGNAL(done(int)), m_netinterfaces, SLOT(updateInterfaces(int)));

    connect(m_usbmanage, SIGNAL(usbStateChanged(bool)), this, SIGNAL(usbStatusChanged()));
    connect(m_usbmanage, SIGNAL(usbStateChanged(bool)), this, SLOT(usbStatus()));


    connect(m_netinterfaces, SIGNAL(config_ifaces()), m_editinterface, SLOT(configureQml()));



    connect(m_netinterfaces, SIGNAL(finished(QString &,QString &)), this, SLOT(updateIP(QString &,QString &)));
    connect(m_netinterfaces, SIGNAL(finished_wlan(QString &,QString &)), this, SLOT(updateWlanIP(QString &,QString &)));



    this->stackedWidget_qml = new QStackedWidget();
    this->view = this;
    this->view->setResizeMode(QDeclarativeView::SizeRootObjectToView);// SizeViewToRootObject);
    this->view->rootContext()->setContextProperty("myWindow",this);
    this->view->rootContext()->setContextProperty("vncProcess",m_vncProcess); /*vnc code*/
    this->view->setSource(QUrl("qrc:/qml_files/RootWindow.qml"));

    /*to stop the animation*/ //NNN
    QObject *obj = this->view->rootObject();

    connect(this, SIGNAL(loadSdkConnectivityScreen()), obj, SLOT(loadSdkConnectivityScreen()));
    connect(m_netinterfaces, SIGNAL(loadSdkConnectivityScreenFromEdit()), obj, SLOT(loadSdkConnectivityScreenFromEdit()));

    m_passwd->generate();

    connect(m_passwd, SIGNAL(passwordAvailable(QString &)), this, SLOT(updatePassword(QString &)));

    /* Connecting Minimizing/Maximizing events*/
    connect(this, SIGNAL(maxScreen()), obj, SLOT(maxScreen()));
    connect(this, SIGNAL(minScreen()), obj, SLOT(minScreen()));




#if HACK_fWS
    setFixedWidth(848);
#endif
    setWindowTitle(MD_TR("SDK Connectivity Tool"));
    DOUT;
}

// Hmm, if help window was child of this this method
// would not have been written...
void
MainWindow::closeEvent(QCloseEvent * event)
{
    DIN;
    (void)event;

    if(stackedWidget_qml != 0)
    {
        delete stackedWidget_qml;
        stackedWidget_qml = 0;
    }

    if(m_netinterfaces != 0)
    {
        delete m_netinterfaces;
        m_netinterfaces = 0;
    }

    if(m_editinterface != 0)
    {
        delete m_editinterface;
        m_editinterface = 0;
    }

    if(m_passwd != 0)
    {
        delete m_passwd;
        m_passwd = 0;
    }

    if(m_usbmanage != 0)
    {
        delete m_usbmanage;
        m_usbmanage = 0;
    }

    if(m_runner != 0)
    {
        delete m_runner;
        m_runner = 0;
    }

    if(m_userRunner != 0)
    {
        delete m_userRunner;
        m_userRunner = 0;
    }

    /*vnc code*/
    if(m_vncProcess != 0)
    {
        m_vncProcess->stop_exec();
        delete m_vncProcess;
        m_vncProcess = 0;
    }

    m_app->quit();
    DOUT;
}

void
MainWindow::usbStatus()
{
    DIN;
    QObject *obj = this->view->rootObject();

    if(this->isUsbConnected() == true)
    {
        QMetaObject::invokeMethod(obj,"usbConnected");
    }
    else
    {
        QMetaObject::invokeMethod(obj,"usbNotConnected");
    }
    DOUT;
}

void
MainWindow::resetPasswd()
{
    DIN;
    NULLCHECK(m_passwd);
    m_passwd->reset();
    DOUT;
}

void
MainWindow::newPassword()
{
    DIN;
    NULLCHECK(m_passwd);
    m_passwd->generate();
    connect(m_passwd, SIGNAL(passwordAvailable(QString &)), this, SLOT(updatePassword(QString &)));
    DOUT;
}

void
MainWindow::setUserPassword(QString userPassword)
{
    DIN;
    //qDebug() << "in Qt setUserPassword, userPassword = " <<userPassword;
    NULLCHECK(m_userRunner);

    QString temp_password(userPassword.size(), QChar('*'));
    QVariant variantPasswd(temp_password);
    QObject *obj = this->view->rootObject();
    QMetaObject::invokeMethod(obj,"setUserPasswordFromQt", Q_ARG(QVariant,variantPasswd));

    m_userRunner->start(QString(PASSWORD_SH), QStringList(userPassword));
    DOUT;
}

void
MainWindow::configureUsb(QString usbIpVal, QString usbNetmaskVal, QString peerIpVal, bool dhcpSelect)
{
    DIN;
    NULLCHECK(m_editinterface);

    m_editinterface->updateUsbConfiguration(usbIpVal, usbNetmaskVal, peerIpVal, dhcpSelect);
    m_editinterface->configureQml();
    DOUT;
}

//WLAN
void
MainWindow::getWlanIp()
{
    DIN;
    NULLCHECK(m_netinterfaces);

    m_netinterfaces->updateInterfaces(0);
    DOUT;
}


void
MainWindow::updateEdit()
{
    DIN;
    NULLCHECK(m_editinterface);

    NetI neti;
    m_editinterface->read_config(neti);

    QVariant ipAdd(neti.address);
    QVariant netmask(neti.netmask);
    QVariant peerip(neti.peerip);
    QVariant dhcpSelectVal(neti.dhcpValue);

    QObject *obj = this->view->rootObject();
    QMetaObject::invokeMethod(obj,"updateDetailsToEdit", Q_ARG(QVariant,ipAdd), Q_ARG(QVariant,netmask),  Q_ARG(QVariant,peerip),  Q_ARG(QVariant,dhcpSelectVal));
    DOUT;
}

void
MainWindow::setUSBConfig()
{
    DIN;
    NULLCHECK(m_netinterfaces);

    this->selectConnectionScreen = true;
    this->usbStatus();
    emit usbStatusChanged();
    m_netinterfaces->setSelectedConfigType(NetInterfaces::CONFIG_USB);

    configUSBLinux(); //nnn added
    DOUT;
}

void
MainWindow::setWLANConfig()
{
    DIN;
    NULLCHECK(m_netinterfaces);

    m_netinterfaces->setSelectedConfigType(NetInterfaces::CONFIG_WLAN);
    DOUT;
}

bool
MainWindow::isUsbConnected()
{
    DIN;
    QFile file("/sys/class/power_supply/usb/uevent");
    if (file.open(QIODevice::ReadOnly))
    {
        QByteArray data = file.readAll();
        QString dataStr = data.data();
        QStringList lineData = dataStr.split("\n");
        bool status = false;
        bool status1 = false;
        foreach(QString str,lineData)
        {
            QStringList temp = str.split("=");
            if((temp.at(0) == "POWER_SUPPLY_TYPE") && (temp.at(1) == "USB"))
            {
                status = true;
            }

            if((temp.at(0) == "POWER_SUPPLY_PRESENT") && (temp.at(1) == "1"))
            {
                status1 = true;
            }
        }

        if(status && status1) {
            DOUT;
            return true;
        }
        else
        {
            DOUT;
            return false;
        }

    }
    else
    {
        DOUT;
        return false;
    }
}

void
MainWindow::updatePassword(QString &password)
{
    DIN;
    //qDebug()<<__FILE__<<__FUNCTION__<<__LINE__<<"\n";
    QObject *obj = this->view->rootObject();
    QMetaObject::invokeMethod(obj,"getPasswdFromQt", Q_ARG(QVariant,password));
    disconnect(m_passwd, SIGNAL(passwordAvailable(QString &)), this, SLOT(updatePassword(QString &)));
    DOUT;
}

void
MainWindow::updatePasswordForWlan(QString &password)
{
    DIN;
    //qDebug()<<__FILE__<<__FUNCTION__<<__LINE__<<"\n";
    QObject *obj = this->view->rootObject();
    QMetaObject::invokeMethod(obj,"getPasswdFromQt", Q_ARG(QVariant,password));
    DOUT;
}

void
MainWindow::updateIP(QString &ip, QString &netmask)
{
    DIN;
    //qDebug()<<__FILE__<<__FUNCTION__<<__LINE__<<"ip ="<<ip;

    if( (ip.contains("-") ) || (ip.isEmpty()) || ip.isNull() )
    {
        ip = "0.0.0.0";
    }

    QVariant usbIpVar(ip);
    QVariant usbMaskVar(netmask);

    QObject *obj = this->view->rootObject();
    QMetaObject::invokeMethod(obj,"getUsbIpFromQt", Q_ARG(QVariant,usbIpVar), Q_ARG(QVariant,usbMaskVar));

    if(this->selectConnectionScreen == true)
    {
        emit loadSdkConnectivityScreen();
        this->selectConnectionScreen = false;
    }
    DOUT;
}

void
MainWindow::configUSBLinux()
{
    DIN;
    NULLCHECK(m_editinterface);

    NetI neti;
    m_editinterface->read_config(neti);

    /*modified true from neti.dhcpValue to send user selected value instead of true every time*/
    m_editinterface->updateUsbConfiguration(neti.address,neti.netmask,neti.peerip,neti.dhcpValue,EditInterface::CONFIG_USB);

    m_editinterface->configureQml();
    DOUT;
}

void
MainWindow::updateWlanIP(QString &ip, QString &netmask)
{
    DIN;
    //qDebug()<<__FILE__<<__FUNCTION__<<__LINE__<<"\n";

    if( (ip.contains("-") ) || (ip.isEmpty()) || ip.isNull() )
    {
        ip = "0.0.0.0";
    }

    QVariant wlanIpVar(ip);
    QVariant wlanMaskVar(netmask);

    QObject *obj = this->view->rootObject();
    QMetaObject::invokeMethod(obj,"getWlanIpFromQt", Q_ARG(QVariant,wlanIpVar), Q_ARG(QVariant,wlanMaskVar));
    DOUT;
}

/*vnc process code*/

void
MainWindow::vncSaveToFile(QString content)
{
    DIN;
    //qDebug()<<__FILE__<<__FUNCTION__<<__LINE__<<"Content:"<<content;

    QDateTime currentDateTime = QDateTime::currentDateTime();
    QString tempPath = QDir::tempPath();
    QString fileName = tempPath+"/vnc_output_" + currentDateTime.toString().replace(" ","_");
    QFile file(fileName);

    //qDebug()<<"fileName = "<<fileName;

    if( !file.open(QIODevice::WriteOnly | QIODevice::Text))
    {
        qDebug()<<"nnn Failed to open "<<file.error();
        this->m_fileName = "ERROR";
    }

    QTextStream out(&file);
    out <<content<<"\n";

    this->m_fileName = fileName;
    emit fileSaved();
    DOUT;
}

void
MainWindow::vncProcessStart(QString vncIp, QString passwd, bool viewOnly)
{
    DIN;
    NULLCHECK(m_vncProcess);

    setViewOnly(viewOnly);
    setVncPasswd(passwd);
    setVncIp(vncIp);

    //qDebug()<<"nnn"<<__FILE__<<__FUNCTION__<<__LINE__;
    m_vncProcess->start_exec(vncIp, passwd, isViewOnly());
    emit vncStarted();
    DOUT;
}

void
MainWindow::vncProcessStop()
{
    DIN;
    //qDebug()<<"nnn"<<__FILE__<<__FUNCTION__<<__LINE__;
    NULLCHECK(m_vncProcess);

    m_vncProcess->stop_exec();
    emit vncStopped();
    DOUT;
}

/*Event occurs when minimize/maximize the application*/
void
MainWindow::changeEvent(QEvent *event)
{
    DIN;
    if(event->type() == QEvent::WindowStateChange) {
        if(isMinimized())
        {
            qDebug()<<"isMinimized true";
            emit minScreen();
        }
        else
        {
            qDebug()<<"isMinimized false";
            emit maxScreen();
        }
    }
    DOUT;
}
