#ifndef _MAINWINDOW_H
#define _MAINWINDOW_H

#include "common.h"
#include <QObject>
#include <QMainWindow>
#include <QDebug>
#include <QDeclarativeView>
#include <QDeclarativeContext>

class QStackedWidget;
class QApplication;

class NetInterfaces;
class Passwd;
class EditInterface;
class UsbManage;
class ProcessRunner;
class vncProcessManager;

class MainWindow : public QDeclarativeView
{
     Q_OBJECT
    Q_PROPERTY(bool connectedUsb READ isUsbConnected NOTIFY usbStatusChanged)
    Q_PROPERTY(QString fileName READ fileName NOTIFY fileSaved)
    Q_PROPERTY(QString vncPasswd READ vncPasswd WRITE setVncPasswd NOTIFY vncPasswdChanged)
    Q_PROPERTY(bool viewOnly READ isViewOnly WRITE setViewOnly NOTIFY vncViewOnlyChanged)
    Q_PROPERTY(QString vncIp READ vncIp WRITE setVncIp NOTIFY vncIpChanged)
    //Q_PROPERTY(QString wlanGateway READ getWlanGateway)

private:
    QString m_fileName;

public:
     MainWindow(QApplication *parent);
     QString fileName() const {return m_fileName;}

public slots:
        void usbStatus();
        void configureUsb(QString usbIpVal, QString usbNetmaskVal, QString peerIpVal, bool dhcpSelect);
        void resetPasswd();
        void getWlanIp();
        //QString getWlanGateway();
        void updateEdit();
        void setUSBConfig();
        void setWLANConfig();
        bool isUsbConnected();
        void updatePasswordForWlan(QString &password);
        void updateIP(QString &ip,QString &netmask);
        void configUSBLinux();
        void updateWlanIP(QString &ip,QString &netmask);
        void updatePassword(QString &password);
        //void getPassword();
        void newPassword();
        void setUserPassword(QString userPassword);

        /*vnc code*/
        void vncSaveToFile(QString content);
        void vncProcessStart(QString vncIp, QString passwd, bool viewOnly);
        Q_INVOKABLE void vncProcessStop();

        QString vncIp() { return m_sVncIp; }
        void setVncIp(QString ip) { m_sVncIp = ip; emit vncIpChanged(); }

        QString vncPasswd() { return m_sVncPasswd; }
        void setVncPasswd(QString passwd) { m_sVncPasswd = passwd; emit vncPasswdChanged(); }
        bool isViewOnly() { return m_bVncViewOnly; }
        void setViewOnly(bool viewOnly) { m_bVncViewOnly = viewOnly; emit vncViewOnlyChanged(); }

signals:
        void usbStatusChanged();
        void loadSdkConnectivityScreen();
        void fileSaved();
        void vncPasswdChanged();
        void vncViewOnlyChanged();
        void vncIpChanged();
        void vncStarted();
        void vncStopped();
        void maxScreen();
        void minScreen();


private:
	QApplication * m_app;
	NetInterfaces *m_netinterfaces;
	Passwd *m_passwd;
        QString m_sVncPasswd;
        QString m_sVncIp;
        bool m_bVncViewOnly;
        //Passwd * m_passwd_wlan;
        //Passwd * m_passwd_qml;

	UsbManage *m_usbmanage;
	EditInterface *m_editinterface;
        EditInterface *m_editinterfaceForLinux;
        ProcessRunner *m_runneForLinuxr;
        ProcessRunner *m_userRunner;
        /*Shared script runner for m_netinterfaces and m_editinterface*/
	ProcessRunner *m_runner;
	void closeEvent(QCloseEvent * event);
        void changeEvent(QEvent *);

        /*vnc code*/
        vncProcessManager *m_vncProcess;

private:
        QStackedWidget *stackedWidget_qml;
        //bool selectModuleScreen;
        bool selectConnectionScreen;

public:
        QDeclarativeView *view;
        QString usbIp;
        QString usbMask;
        QString wlanIp;
        QString wlanMask;
        QString passwd;
        bool    usbConnected;

};

#endif
