#include <QDebug>

#include "sdk-connectivity-tool.h"
#include "mainwindow.h"
#include "netinterfaces.h"
#include "processrunner.h"

NetInterfaces::NetInterfaces(QObject *obj, ProcessRunner *runner)
    : m_runner(runner),m_selected_config(CONFIG_NONE)
{
    DIN;
    connect(m_runner, SIGNAL(finished(int)),
            this, SLOT(dataAvailable(int)));
    DOUT;
}

NetInterfaces::~NetInterfaces()
{
    DIN;
    //destructor
    m_runner->deleteLater();
    DOUT;
}

void
NetInterfaces::addLine(const QString &name, const QString &ip,
		       const QString &netmask, const QString &flags)
{
    DIN;
    Q_UNUSED(flags);
    QString ip1 = ip;
    QString netmask1 = netmask;


    if ( ( name.contains("usb") ) && (m_selected_config == CONFIG_USB) )
    {
        //m_selected_config = CONFIG_NONE;
        emit finished(ip1,netmask1);
    }
    else if( ( name.contains("wlan") ) && (m_selected_config == CONFIG_WLAN) )
    {
        //m_selected_config = CONFIG_NONE;
        emit finished_wlan(ip1,netmask1);
    }

    DOUT;
}

void
NetInterfaces::setSelectedConfigType(int value)
{
    DIN;
    m_selected_config = value;
    DOUT;
}

int
NetInterfaces::selectedConfigType()
{
    DIN;
    DOUT;
    return m_selected_config;
}


void
NetInterfaces::updateInterfaces(int do_config_ifaces)
{
    DIN;
    if (do_config_ifaces)
	emit config_ifaces();
    else
	m_runner->start(QString(INTERFACES_SH), (QStringList)0);
    DOUT;
}

void
NetInterfaces::dataAvailable(int exitCode)
{

    DIN;
    emit loadSdkConnectivityScreenFromEdit();
    if (exitCode != 0) {
        qDebug() << "Err" << m_runner->getStderr();
        DOUT;
        return;
    } else {
        //clear();
        QList<QByteArray> out = m_runner->getStdout();

        for(int i = 0; i < out.size(); i++)

        // Line format: iface ip mask flags
        for (int i = 0; i < out.size(); i++) {
            QList<QByteArray> f = out.at(i).split(' ');
            if (f.size() < 5)
                continue;
            addLine(f.at(0), f.at(1), f.at(2), f.at(3));
        }
    }
    DOUT;
}
