#include "processmanager.h"
#include <QDebug>


vncProcessManager::vncProcessManager(QDeclarativeItem *parent) :
    QDeclarativeItem(parent)
{
    DIN;
    //qDebug()<<"nnn "<<__FILE__<<__FUNCTION__<<__LINE__;
    m_ipaddr= "0.0.0.0";
    m_process.setProcessChannelMode(QProcess::MergedChannels);
    connect(&m_process, SIGNAL(readyReadStandardOutput()),this, SLOT(slotReadyReadStandardOutput()));
    connect(&m_process, SIGNAL(stateChanged(QProcess::ProcessState)),this, SLOT(slotProcStateChanged ( QProcess::ProcessState)));
    connect(&m_process, SIGNAL(error(QProcess::ProcessError)),this, SLOT(slotErrorStatusChanged ( QProcess::ProcessError)));
    connect(&m_process, SIGNAL(finished(int, QProcess::ExitStatus)),this, SLOT(slotProcFinished(int, QProcess::ExitStatus)));

    m_logdata.clear();
    m_errorstatus.clear();

    m_timer = new QTimer(this);
    connect(m_timer, SIGNAL(timeout()), this, SLOT(timerTask()));
    //m_timer->start(LOG_REFRESH_RATE);
    DOUT;
}

vncProcessManager::~vncProcessManager() {
    DIN;
    if (m_process.state()==QProcess::Running) {
        m_process.terminate();
    }
    m_timer->stop();
    m_timer->deleteLater();
    DOUT;
}

void vncProcessManager::start_exec(QString vncIp, QString passwd, bool viewOnly)
{
    DIN;
    //qDebug()<<"nnn "<<__FILE__<<__FUNCTION__<<__LINE__;
    if (m_timer!=NULL) { m_timer->start(LOG_REFRESH_RATE); }

    m_logdata.clear();
    m_errorstatus.clear();
    m_ipaddr = (vncIp);

    emit errorStatusChanged();

    cleanAll();
    //qDebug() << "nnn start_exec called" << m_ipaddr;

    QStringList args;

    // lets not set a password if it is empty
    if (passwd!="") {
        args << "-passwd" << passwd;
    }

    // lets enable view only mode
    if (viewOnly) {
        args << "-viewonly";
    }
    args << "-shared";
    args << "-forever";
    args << "-touchdev Atmel";
    args << "-listen" << m_ipaddr;

    m_process.start("x11vnc " + args.join(" "));
    DOUT;
}

void vncProcessManager::stop_exec()
{
    //qDebug()<<"nnn "<<__FILE__<<__FUNCTION__<<__LINE__;
    //qDebug() << "stop_exec called";
    if (m_timer!=NULL) { m_timer->stop(); }
    m_process.terminate();
    cleanAll();
}

void vncProcessManager::slotReadyReadStandardOutput()
{    
    //qDebug()<<"nnn "<<__FILE__<<__FUNCTION__<<__LINE__;
    while (m_process.canReadLine())
    {
        m_mutex.lock();
        m_logdata += QString::fromLocal8Bit(m_process.readLine());
        m_mutex.unlock();
    }
}

void vncProcessManager::slotProcStateChanged ( QProcess::ProcessState newState )
{
    //qDebug()<<"nnn "<<__FILE__<<__FUNCTION__<<__LINE__;
    //qDebug() << "process state changed:" << newState;
    m_procstatus = newState;
    emit procStatusChanged();
    if (newState == 2)
    {
        m_errorstatus = "Running on: " + m_ipaddr;
        emit errorStatusChanged();
    }
}


void vncProcessManager::timerTask()
{
    //qDebug()<<"nnn "<<__FILE__<<__FUNCTION__<<__LINE__;
    if ( m_mutex.tryLock() )
    {
        if (m_logdata.length() != 0 )
        {
            emit logDataChanged();
            m_logdata.clear();
        }
        m_mutex.unlock();
    }

}


void vncProcessManager::slotErrorStatusChanged(QProcess::ProcessError error)
{

    //qDebug()<<"nnn "<<__FILE__<<__FUNCTION__<<__LINE__;
    //qDebug() << "process error:" << error;

    switch (error){

    case QProcess::FailedToStart:
        m_errorstatus = "Failed to start";
        break;
    case QProcess::Crashed:
        m_errorstatus = "Process crashed";
        break;
    case QProcess::ReadError:
        m_errorstatus = "Error while reading";
        break;
    default:
        m_errorstatus ="Unexpected error";
    }

    emit errorStatusChanged();

}

void vncProcessManager::slotProcFinished (int exitCode, QProcess::ExitStatus exitStatus)
{
    //qDebug()<<"nnn "<<__FILE__<<__FUNCTION__<<__LINE__;
    QString strExitStat = exitStatus ? "normal":"crashed";
    m_errorstatus = "Finished: " + strExitStat + ", exit code: " + QString::number(exitCode);
    emit errorStatusChanged();
}


void vncProcessManager::slotAboutQuit()
{
    //qDebug()<<"nnn "<<__FILE__<<__FUNCTION__<<__LINE__;
    m_process.terminate();
    cleanAll();
}


void vncProcessManager::cleanAll()
{
    //qDebug()<<"nnn "<<__FILE__<<__FUNCTION__<<__LINE__;
    system("killall x11vnc");
}
