#include <QString>
#include <qdebug.h>

#include "sdk-connectivity-tool.h"
#include "processrunner.h"

ProcessRunner::ProcessRunner()
{
    DIN;
    m_proc = new QProcess(this);

    m_proc->setEnvironment(QProcess::systemEnvironment());
    connect(m_proc, SIGNAL(readyReadStandardOutput()), this, SLOT(bufferStdout()));
    connect(m_proc, SIGNAL(readyReadStandardError()), this, SLOT(bufferStderr()));
    connect(m_proc, SIGNAL(finished(int, QProcess::ExitStatus)),
            this, SLOT(complete(int, QProcess::ExitStatus)));
    DOUT;
}


ProcessRunner::~ProcessRunner()
{
    DIN;
    //qDebug()<<"ProcessRunner::Destructor"<<__FILE__<<__LINE__;
    if(m_proc != 0 )
    {
        delete m_proc;
        m_proc = 0;
    }
    DOUT;
}

int
ProcessRunner::start(const QString &name, const QStringList &args)
{
    DIN;
    NULLCHECK_INT(m_proc);

    int ec = 0;
    if (m_proc->state() == QProcess::NotRunning) {
        m_stdout.clear();
        m_stderr.clear();
        if (args.at(0) == "")
            m_proc->start(name);
        else
            m_proc->start(name, args);
    } else {
        ec = 1;
    }

    DOUT;
    return ec;
}

QList<QByteArray> &
ProcessRunner::getStdout(void)
{
    DIN;
    DOUT;
    return m_stdout;
}

QByteArray &
ProcessRunner::getStderr(void)
{
    DIN;
    DOUT;
    return m_stderr;
}

void
ProcessRunner::bufferStdout(void)
{
    DIN;
    NULLCHECK(m_proc);

    QByteArray line;
    m_proc->setReadChannel(QProcess::StandardOutput);
    while (!( line = m_proc->readLine() ).isEmpty())
        m_stdout.append(line); // QList<QByteArray> m_stdout;
    DOUT;
}

void
ProcessRunner::bufferStderr(void)
{
    DIN;
    NULLCHECK(m_proc);

    QByteArray line;
    m_proc->setReadChannel(QProcess::StandardError);
    while (!( line = m_proc->readLine() ).isEmpty())
        m_stderr.append(line); // QByteArray m_stderr;
    DOUT;
}

void
ProcessRunner::complete(int exitCode, QProcess::ExitStatus exitStatus)
{
    DIN;
    Q_UNUSED(exitStatus);
    bufferStdout();
    bufferStderr();

    //qDebug() << this << "done";
    emit finished(exitCode);
    DOUT;
}
