import Qt 4.7
import com.nokia.meego 1.0
import com.nokia.extras 1.0

import "UIConstants.js" as UI

Page {
    id:editSettingsScreen
    orientationLock: PageOrientation.LockPortrait
    tools: navigationToolbar

    property bool dhcpCheck: false
    property bool bSettingsChanged : false
    property variant ipValidator : RegExpValidator { regExp: /((25[0-5 ]|2[0-4 ][0-9 ]|1[0-9 ]{2}|[0-9 ]{1,2})\.){3}(25[0-5 ]|2[0-4 ][0-9 ]|1[0-9 ]{2}|[0-9 ]{1,2})/ }
    property variant noValidator : RegExpValidator {}
    property bool pageLoaded : false;

    Component.onDestruction: {
        ipAddress.text = rootWindow.ipVal;
        mask.text = rootWindow.usbMaskVal;
        host.text = rootWindow.hostIp
    }

    Component.onCompleted: {
        pageLoaded = true;
    }

    InfoBanner {
        id: infoBanner
        anchors.top: parent.top
        anchors.left: parent.left
        anchors.right: parent.right
        text: "Password Changed"
        z: 1000
    }

    PageTitle {
        id: titleName
        anchors.top: parent.top
        width: parent.width
        text: "Edit Settings"
    }

    Image {
        id: appIcon
        anchors.top: titleName.top
        anchors.right: titleName.right
        anchors.rightMargin: 10
        anchors.topMargin: 10
        height: titleName.height - 20
        width: height
        z: 20

        source: (rootWindow.connectionType === "USB") ? "image://theme/icon-m-common-usb" : "image://theme/icon-m-common-wlan" //rootWindow.usbImageSource
        smooth: true
        //visible: (rootWindow.connectionType === "USB")
    }

    Flickable {
        id: flickableArea
        width: parent.width
        anchors.top: titleName.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.margins: UI.HEADER_DEFAULT_TOP_SPACING_PORTRAIT
        contentWidth: pageContent.width
        contentHeight: pageContent.height

        Column {
            id: pageContent
            spacing: 20

            SectionHeader {
                id: networkSectionHeader
                text: "Network"
                width: flickableArea.width
            }

            Column {
                id: editSettingsDisabledColumn
                spacing: 8
                visible: rootWindow.vncSwitchStatus
                Row {
                    width: pageContent.width
                    Label {
                        text: "You can not modify the network settings while VNC server is running."
                        platformStyle: LabelStyle {
                            fontFamily: UI.FONT_FAMILY_LIGHT
                            fontPixelSize: UI.FONT_DEFAULT
                            textColor: UI.COLOR_INVERTED_SECONDARY_FOREGROUND
                        }
                        width: parent.width
                        wrapMode: Text.WordWrap
                    }
                }
            }

            Column {
                id:editSettingsColumn
                spacing:8
                visible: !rootWindow.vncSwitchStatus

                Row {
                    id:dhcpRow
                    spacing: 20
                    width: flickableArea.width

                    Label {
                        id: dhcpText
                        text: (rootWindow.connectionType === "WLAN") ? "Automatic from WLAN" : "Run DHCP Server on USB"
                        anchors.verticalCenter: parent.verticalCenter
                        width: parent.width - parent.spacing - dhcpCheckBox.width
                        platformStyle: LabelStyle {
                            fontFamily: UI.FONT_FAMILY
                            fontPixelSize: UI.FONT_SLARGE
                        }
                        color: "#797979"
                    }

                    Switch {
                        id:dhcpCheckBox
                        enabled: rootWindow.connectionType !== "WLAN" && !rootWindow.vncSwitchStatus
                        checked: rootWindow.connectionType === "WLAN" ? true: rootWindow.dhcpSelectStatus
                        onCheckedChanged: {
                            if (!pageLoaded) { return; }

                            bSettingsChanged = true;
                            dhcpCheck = dhcpCheckBox.checked;
                            ipAddress.platformCloseSoftwareInputPanel();
                            mask.platformCloseSoftwareInputPanel();
                            host.platformCloseSoftwareInputPanel();
                            if (checked) {
                                ipAddress.validator = ipValidator;
                                mask.validator = ipValidator;
                                host.validator = ipValidator;
                                if (ipAddress.acceptableInput === false || mask.acceptableInput === false || host.acceptableInput === false) {
                                    infoBanner.text = "Invalid network settings :(";
                                    infoBanner.show();
                                    ipAddress.validator = noValidator;
                                    mask.validator = noValidator;
                                    host.validator = noValidator;
                                    dhcpCheckBox.checked = false;
                                    return;
                                }
                                ipAddressLabel.text = ipAddress.text;
                                ipAddress.validator = noValidator;
                                maskLabel.text = mask.text;
                                mask.validator = noValidator;
                                hostLabel.text = host.text;
                                host.validator = noValidator;

                                myWindow.configureUsb(ipAddress.text, mask.text, host.text, dhcpCheck );

                            } else {
                                ipAddress.validator = ipValidator;
                                mask.validator = ipValidator;
                                host.validator = ipValidator;
                                if (ipAddress.acceptableInput === false || mask.acceptableInput === false || host.acceptableInput === false) {
                                    infoBanner.text = "Invalid network settings :(";
                                    infoBanner.show();
                                    ipAddress.validator = noValidator;
                                    mask.validator = noValidator;
                                    host.validator = noValidator;
                                    dhcpCheckBox.checked = false;
                                    return;
                                }
                                ipAddressLabel.text = ipAddress.text;
                                ipAddress.validator = noValidator;
                                maskLabel.text = mask.text;
                                mask.validator = noValidator;
                                hostLabel.text = host.text;
                                host.validator = noValidator;
                            }
                        }
                    }
                }

                Row {
                    width: flickableArea.width
                    spacing: 20
                    //visible: rootWindow.connectionType !== "WLAN"

                    Label {
                        id: ipAddressText
                        text: "IP Address"
                        anchors.verticalCenter: parent.verticalCenter
                        width: parent.width - parent.spacing - ( ipAddressLabel.visible ? ipAddressLabel.width : ipAddress.width )
                        platformStyle: LabelStyle {
                            fontFamily: UI.FONT_FAMILY
                            fontPixelSize: UI.FONT_LSMALL
                        }
                        color: "#797979"
                    }

                    LabelValue {
                        id: ipAddressLabel
                        anchors.verticalCenter: parent.verticalCenter
                        visible: dhcpCheckBox.checked
                        width:(flickableArea.width/1.5)
                        text: rootWindow.connectionType[0] === "U" ? rootWindow.ipVal : rootWindow.ipValWlan
                        color: ipAddressLabel.text !== "0.0.0.0" ? "white" : "#fe3200"
                    }

                    TextField {
                        id:ipAddress
                        width:(flickableArea.width/1.5)
                        visible: rootWindow.connectionType !== "WLAN" || !dhcpCheckBox.checked
                        text:rootWindow.connectionType[0] === "U" ? rootWindow.ipVal : rootWindow.ipValWlan
                        inputMethodHints: Qt.ImhDigitsOnly
                        readOnly: rootWindow.connectionType === "WLAN" ? true: (dhcpCheckBox.checked && !rootWindow.vncSwitchStatus)
                        platformStyle: TextFieldStyle {
                            textColor: ipAddress.readOnly ? UI.COLOR_DISABLED_FOREGROUND : UI.COLOR_FOREGROUND
                        }
                        onTextChanged: {
                            bSettingsChanged = true;
                        }

                        onActiveFocusChanged: {
                            if (ipAddress.focus==false) {
                                platformCloseSoftwareInputPanel();
                            }
                        }

                        Keys.onEnterPressed: {
                            platformCloseSoftwareInputPanel();
                            focus = false;
                        }

                        Keys.onReturnPressed: {
                            platformCloseSoftwareInputPanel();
                            focus = false;
                        }
                    }
                }
                Row {
                    width: flickableArea.width
                    spacing: 20
                    //visible: rootWindow.connectionType !== "WLAN"

                    Label {
                        id: maskText
                        text: "Netmask"
                        anchors.verticalCenter: parent.verticalCenter
                        width: parent.width - parent.spacing - ( maskLabel.visible ? maskLabel.width : mask.width )
                        platformStyle: LabelStyle {
                            fontFamily: UI.FONT_FAMILY
                            fontPixelSize: UI.FONT_LSMALL
                        }
                        color: "#797979"
                    }

                    LabelValue {
                        id: maskLabel
                        anchors.verticalCenter: parent.verticalCenter
                        visible: dhcpCheckBox.checked
                        width:(flickableArea.width/1.5)
                        text: rootWindow.connectionType[0] === "U" ? ((rootWindow.usbMaskVal === "-") ? "255.255.255.0" : rootWindow.usbMaskVal ) : ((rootWindow.wlanMaskVal === "-") ? "255.255.255.0" : rootWindow.wlanMaskVal )
                        color: maskLabel.text !== "-" ? "white" : "#fe3200"
                    }

                    TextField {
                        id:mask
                        width:(flickableArea.width/1.5)
                        text: rootWindow.connectionType[0] === "U" ? rootWindow.usbMaskVal : rootWindow.wlanMaskVal
                        inputMethodHints: Qt.ImhDigitsOnly
                        readOnly: rootWindow.connectionType === "WLAN"? true : (dhcpCheckBox.checked && !rootWindow.vncSwitchStatus)
                        visible: rootWindow.connectionType !== "WLAN" || !dhcpCheckBox.checked
                        platformStyle: TextFieldStyle {
                            textColor: mask.readOnly ? UI.COLOR_DISABLED_FOREGROUND : UI.COLOR_FOREGROUND
                        }
                        onTextChanged: {
                            bSettingsChanged = true;
                        }

                        onActiveFocusChanged: {
                            if (mask.focus==false) {
                                platformCloseSoftwareInputPanel();
                            }
                        }

                        Keys.onEnterPressed: {
                            platformCloseSoftwareInputPanel();
                            focus = false;
                        }

                        Keys.onReturnPressed: {
                            platformCloseSoftwareInputPanel();
                            focus = false;
                        }
                    }
                }
                Row {
                    width: flickableArea.width
                    spacing: 20
                    visible: rootWindow.connectionType !== "WLAN"

                    Label {
                        id: hostText
                        text: "Host"
                        anchors.verticalCenter: parent.verticalCenter
                        width: parent.width - parent.spacing - ( hostLabel.visible ? hostLabel.width : host.width )
                        platformStyle: LabelStyle {
                            fontFamily: UI.FONT_FAMILY
                            fontPixelSize: UI.FONT_LSMALL
                        }
                        color: "#797979"
                    }

                    LabelValue {
                        id: hostLabel
                        anchors.verticalCenter: parent.verticalCenter
                        visible: (rootWindow.connectionType !== "WLAN" && dhcpCheckBox.checked)
                        width:(flickableArea.width/1.5)
                        text: rootWindow.hostIp
                        color: "white"
                    }

                    TextField {
                        id:host
                        width:(flickableArea.width/1.5)
                        visible: (rootWindow.connectionType !== "WLAN" && !dhcpCheckBox.checked)
                        text: rootWindow.hostIp
                        readOnly: rootWindow.connectionType === "WLAN"? true : (dhcpCheckBox.checked && !rootWindow.vncSwitchStatus)
                        inputMethodHints: Qt.ImhDigitsOnly
                        platformStyle: TextFieldStyle {
                            textColor: host.readOnly ? UI.COLOR_DISABLED_FOREGROUND : UI.COLOR_FOREGROUND
                        }
                        onTextChanged: {
                            bSettingsChanged = true;
                        }

                        onActiveFocusChanged: {
                            if (host.focus==false) {
                                platformCloseSoftwareInputPanel();
                            }
                        }

                        Keys.onEnterPressed: {
                            platformCloseSoftwareInputPanel();
                            focus = false;
                        }

                        Keys.onReturnPressed: {
                            platformCloseSoftwareInputPanel();
                            focus = false;
                        }
                    }
                }
            }

            Row {
                spacing: UI.HEADER_DEFAULT_TOP_SPACING_PORTRAIT*2
                width: flickableArea.width - UI.HEADER_DEFAULT_TOP_SPACING_PORTRAIT*2
                visible: !dhcpCheckBox.checked && !rootWindow.vncSwitchStatus

                Button {
                    id:defaultSettingsButton
                    text:"Reset"
                    width: parent.width/2
                    visible: rootWindow.connectionType === "USB" ? true : false
                    enabled: !dhcpCheckBox.checked && !rootWindow.vncSwitchStatus
                    onClicked:{
                        console.log("Restore default settings");
                        ipAddress.text          =   "192.168.2.15";
                        ipAddressLabel.text = ipAddress.text;
                        mask.text               =   "255.255.255.0";
                        maskLabel.text = mask.text;
                        host.text               =   "192.168.2.14";
                        hostLabel.text = host.text;
                        dhcpCheckBox.checked    =   true;
                        infoBanner.text = "Network Settings restored!";
                        infoBanner.show();
                        bSettingsChanged = true;
                    }
                }

                Button {
                    id: buttonLeft; text: "Save"
                    width: parent.width/2
                    visible: rootWindow.connectionType=="USB"?true:false
                    enabled: (!dhcpCheckBox.checked && bSettingsChanged && !rootWindow.vncSwitchStatus)
                    onClicked: {
                        ipAddress.platformCloseSoftwareInputPanel();
                        mask.platformCloseSoftwareInputPanel();
                        host.platformCloseSoftwareInputPanel();

                        ipAddress.validator = ipValidator;
                        mask.validator = ipValidator;
                        host.validator = ipValidator;

                        if (ipAddress.acceptableInput===false || mask.acceptableInput===false || host.acceptableInput===false) {
                            infoBanner.text = "Invalid network settings :(";
                            infoBanner.show();
                            ipAddress.validator = noValidator;
                            mask.validator = noValidator;
                            host.validator = noValidator;
                            return;
                        }
                        ipAddress.validator = noValidator;
                        mask.validator = noValidator;
                        host.validator = noValidator;

                        if(dhcpCheckBox.checked === true)
                        {
                            dhcpCheck = true;
                            myWindow.configureUsb(ipAddress.text, mask.text, host.text, dhcpCheck );
                        }
                        else
                        {
                            dhcpCheck = false;
                            myWindow.configureUsb(ipAddress.text, mask.text, host.text, dhcpCheck );
                        }


                        infoBanner.text = "Network Settings saved!";
                        infoBanner.show();
                        bSettingsChanged = false;

                        //pageStack.push("qrc:/qml_files/WaitingScreen.qml");
                    }
                }
            }

            SectionHeader {
                text: "Developer Account"
                width: flickableArea.width
            }

            Column {
                id:passwordColumn
                spacing: 20

                Row {
                    width: flickableArea.width
                    spacing: 20

                    Label {
                        text: "Use custom password"
                        anchors.verticalCenter: parent.verticalCenter
                        width: parent.width - parent.spacing - useCustomPassword.width
                        platformStyle: LabelStyle {
                            fontFamily: UI.FONT_FAMILY
                            fontPixelSize: UI.FONT_SLARGE
                        }
                        color: "#797979"
                    }
                    Switch {
                        id: useCustomPassword
                        checked: rootWindow.userPassword
                        onCheckedChanged: {
                            rootWindow.userPassword = useCustomPassword.checked
                            if (!useCustomPassword.checked) {
                                myWindow.newPassword();
                            }
                        }
                    }
                }



                Row {
                    visible: useCustomPassword.checked
                    id:passwordFBRow
                    spacing: 20
                    width: flickableArea.width

                    Label {
                        id: passwordText
                        anchors.verticalCenter: parent.verticalCenter
                        width: parent.width - parent.spacing - passwordField.width
                        text: "Password"
                        platformStyle: LabelStyle {
                            fontFamily: UI.FONT_FAMILY
                            fontPixelSize: UI.FONT_LSMALL
                        }
                        color: "#797979"
                    }
                    TextField {
                        id:passwordField
                        width:(flickableArea.width/1.5)
                        focus: false
                        maximumLength: 15
                        echoMode: TextInput.Normal
                        text: rootWindow.passwordVal

                        property bool savePassword : false

                        Keys.onEnterPressed: {
                            platformCloseSoftwareInputPanel();
                            doSavePassword();
                            focus = false;
                        }

                        Keys.onReturnPressed: {
                            platformCloseSoftwareInputPanel();
                            doSavePassword();
                            focus = false;
                        }

                        function doSavePassword() {
                            rootWindow.passwordVal = passwordField.text;
                            rootWindow.userPassword = true;
                            myWindow.setUserPassword(passwordField.text);
                            savePassword = false;
                            infoBanner.text = "Password Changed!"
                            infoBanner.show();
                        }

                        onTextChanged:  { // we set the password here because of the virtual keyboard
                            if (savePassword) {
                                doSavePassword();
                            }
                        }
                        onActiveFocusChanged: {
                            if (passwordField.focus==false) {
                                savePassword = true;
                                platformCloseSoftwareInputPanel();
                            }
                        }

                    }
                }

                Row {
                    visible: !useCustomPassword.checked
                    id: autoPasswordFBRow
                    spacing: 20
                    width: flickableArea.width

                    Label {
                        id: autoPasswordText
                        anchors.verticalCenter: parent.verticalCenter
                        width: parent.width - parent.spacing - autoPasswordLabel.width
                        text: "Password"
                        platformStyle: LabelStyle {
                            fontFamily: UI.FONT_FAMILY
                            fontPixelSize: UI.FONT_LSMALL
                        }
                        color: "#797979"
                    }
                    LabelValue {
                        id:autoPasswordLabel
                        width:(flickableArea.width/1.5)
                        color: "white"
                        text: rootWindow.passwordVal

                    }
                }

                Button {
                    visible: !useCustomPassword.checked
                    id:reset
                    text: "Generate Password"
                    anchors.right: parent.right
                    width:(flickableArea.width/1.5)
                    onClicked: {
                        rootWindow.userPassword = false;

                        myWindow.newPassword();
                        infoBanner.text = "Password Generated!";
                        infoBanner.show();
                    }
                }
            }
        }
    }




}
