import QtQuick 1.1
import com.nokia.meego 1.0

import "UIConstants.js" as UIConstants

/*!
 * @brief Page Header
 */
Image {
    id: headerholder

    property string text : ""
    property bool dropShadow : false
    property int themeColor : 1
    property string __selectedAppEffectColor : (!theme.inverted ? ((headerholder.themeColor > 1) ? ("color" + headerholder.themeColor + "-") : "") : "")

    height: parent.width < parent.height ? UIConstants.HEADER_DEFAULT_HEIGHT_PORTRAIT : UIConstants.HEADER_DEFAULT_HEIGHT_LANDSCAPE
    width: parent.width
    source: "image://theme/" + __selectedAppEffectColor + "meegotouch-view-header-fixed" + (theme.inverted ? "-inverted" : "")
    x: 0; y: 0; z: 1

    //! Header container
    Item {
        anchors {
            fill: parent
            topMargin: parent.width < parent.height ? UIConstants.HEADER_DEFAULT_TOP_SPACING_PORTRAIT : UIConstants.HEADER_DEFAULT_TOP_SPACING_LANDSCAPE
            bottomMargin: parent.width < parent.height ? UIConstants.HEADER_DEFAULT_BOTTOM_SPACING_PORTRAIT : UIConstants.HEADER_DEFAULT_BOTTOM_SPACING_LANDSCAPE
            rightMargin: UIConstants.DEFAULT_MARGIN
            leftMargin: UIConstants.DEFAULT_MARGIN
        }
        //! Page header text
        Label {
            id: header
            anchors.verticalCenter: parent.verticalCenter
            anchors.left: parent.left

            platformStyle: LabelStyle {
                textColor: theme.inverted ? UIConstants.COLOR_INVERTED_FOREGROUND : ((themeColor > 1) ? UIConstants.COLOR_INVERTED_FOREGROUND : UIConstants.COLOR_FOREGROUND)
                fontFamily: UIConstants.FONT_FAMILY + " Light"
                fontPixelSize: UIConstants.FONT_XLARGE
            }

            text: headerholder.text
        }
    }
    Rectangle {
        id: gradient;
        visible: dropShadow
        anchors.top: headerholder.bottom

        height: 4
        width: parent.width
        gradient: Gradient {
            GradientStop { position: 0.0; color: "#3D3E3E" }
            GradientStop { position: 1.0; color: "transparent" }
        }
        opacity: 0.5
        z: 1
    }

    Rectangle {
        visible: !dropShadow
        anchors {
            top: headerholder.bottom
            left: parent.left
            right: parent.right
        }
        height: 1
        color: theme.inverted ? "#3D3E3E" : "#CDCECE"
    }
}
