import Qt 4.7
import com.nokia.meego 1.0
import QtQuick 1.1

import "UIConstants.js" as UI

Page {
    id:sdkConnectivityScreen
    orientationLock: PageOrientation.LockPortrait
    tools: sdkConnectivityScreenToolbar

    Component.onCompleted: {
        theme.inverted = true;
        rootWindow.showToolBar = true;
    }

    Component.onDestruction: {
        if (rootWindow.vncSwitchStatus === true) {
            console.log("Stop vnc server");
            rootWindow.vncSwitchStatus = false
            rootWindow.vncTempOutput = ""
            rootWindow.previousVncStatus = false
            myWindow.vncProcessStop();
        }
    }

    function showMessage()
    {
        console.log("in showMessage, page = ")
        flickableArea.opacity = 0.1
        toolIconID.opacity = 0.1
        messageBox.visible = true
    }

    PageTitle {
        id: pageTitle
        anchors.top: parent.top
        width: parent.width
        text: "Connectivity Details"
    }

    Image {
        id: appIcon
        anchors.top: pageTitle.top
        anchors.right: pageTitle.right
        anchors.rightMargin: 10
        anchors.topMargin: 10
        height: pageTitle.height - 20
        width: height
        z: 20

        source: (rootWindow.connectionType === "USB") ? "image://theme/icon-m-common-usb" : "image://theme/icon-m-common-wlan" //rootWindow.usbImageSource
        smooth: true
    }

    Item {
        id: messageBox
        width: 350; height: 250
        z:1
        anchors.top: pageTitle.bottom
        anchors.topMargin: 150
        anchors.left : parent.left
        anchors.leftMargin: 50

        visible: false

        Column {
            anchors.centerIn: parent
            spacing: 10;

            LabelValue {
                id: messageLabel
                anchors.left: parent.left
                anchors.leftMargin: 15
                text: "VNC server is running. \nDo you want to stop it?"
                color: "#FFFFFF"
            }
            Button {
                id:yesButton
                text: "YES"
                onClicked: {
                    pageStack.pop();
                    console.log("clicked YES")
                    if (pageStack.depth===1) {
                        pageStack.push("qrc:/qml_files/ConnectionScreen.qml");
                    }
                }
            }
            Button {
                id:noButton
                text: "NO"
                onClicked: {
                    messageBox.visible = false
                    flickableArea.opacity = 1
                    toolIconID.opacity = 1
                    console.log("clicked NO")
                }
            }
        }
    }

    Flickable {
        id: flickableArea
        width: parent.width
        anchors.top: pageTitle.bottom
        anchors.left: parent.left
        anchors.right: parent.right
        anchors.bottom: parent.bottom
        anchors.margins: UI.HEADER_DEFAULT_TOP_SPACING_PORTRAIT
        flickableDirection: Flickable.VerticalFlick
        contentWidth: pageContent.width
        contentHeight: pageContent.height

    Column {
        id: pageContent
        width: pageWidth
        //anchors.margins: UI.HEADER_DEFAULT_TOP_SPACING_PORTRAIT
        spacing: UI.HEADER_DEFAULT_TOP_SPACING_PORTRAIT


        Column {
            id: detailsCol
            spacing: 20
            //anchors.margins: UI.HEADER_DEFAULT_TOP_SPACING_PORTRAIT
            width: pageWidth - UI.HEADER_DEFAULT_TOP_SPACING_PORTRAIT*2
            Column {
                visible: (rootWindow.connectionType === "USB")
                LabelHeader {
                    id: usbCableConnectedText_1
                    text: "Network interface state"
                }
                LabelValue {
                    id: usbStatus
                    text: rootWindow.usbStatusVal
                    color: rootWindow.usbStatusVal === "Connected" ? "#FFFFFF" : "#fe3200"
                }
            }
            Column {
                visible: (rootWindow.connectionType !== "USB")
                LabelHeader {
                    text: "Network interface state"
                }
                LabelValue {
                    id: wlanStatus
                    text: (rootWindow.ipValWlan === "0.0.0.0") ? "Disconnected" : "Connected"
                    color: rootWindow.ipValWlan === "0.0.0.0" ? "#fe3200" : "#FFFFFF"
                }
            }
            Column {
                LabelHeader {
                    id: connectionText
                    text: "Connection type"
                }

                LabelValue {
                    id: connectionTypeID
                    text: rootWindow.connectionType
                }
            }
            Column {
                LabelHeader {
                    id: ipAddressText
                    text: "IP Address"
                }
                LabelValue {
                    id: ipAddress
                    text: rootWindow.connectionType === "USB"? (rootWindow.usbStatusVal === "Connected" ? rootWindow.ipVal : "0.0.0.0") : rootWindow.ipValWlan
                }
            }

            Column {
                LabelHeader {
                    id: passwordText
                    text: "Password"
                }
                LabelValue {
                    id: passowrd
                    text: /*rootWindow.userPassword? rootWindow.userLabelPassword :*/ rootWindow.passwordVal
                }
            }

            Rectangle {
                height: 1
                width: detailsCol.width
                color: "#797979"
            }


        } // column

        Column {
            id:sdkConnectivityButtonRow
            //anchors.top:detailsCol.bottom
            width: pageWidth - UI.HEADER_DEFAULT_TOP_SPACING_PORTRAIT*2
            spacing: 20

            ListView {
                id: listView
                height: 200
                width: parent.width
                model: ListModel {
                    ListElement {
                        name: "Settings"
                        icon: "image://theme/icon-l-settings"
                    }
                    ListElement {
                        name: "VNC"
                        icon: ""
                    }
                } // model

                delegate: Item {
                    id: listItem
                    height: UI.LIST_ITEM_HEIGHT_DEFAULT
                    width: parent.width
                    anchors.rightMargin: 20


                    BorderImage {
                        id: background
                        anchors.fill: parent
                        visible: mouseArea.pressed
                        source: "image://theme/meegotouch-list-" + (theme.inverted ? "inverted-" : "") + "background-pressed-center"
                    }

                    Row {
                        anchors.fill: parent
                         anchors.rightMargin: 20
                         spacing: 20

                         Image {
                             anchors.verticalCenter: parent.verticalCenter
                             height: parent.height - 20
                             width: height
                             source: (name==="VNC") ? (rootWindow.vncSwitchStatus ? "image://theme/icon-m-common-presence-online" : "image://theme/icon-m-common-presence-offline") : icon
                             smooth: true
                         }
                        Column {
                            anchors.verticalCenter: parent.verticalCenter

                            Label {
                                id: mainText
                                text: name
                                platformStyle: LabelStyle {
                                    fontFamily: UI.FONT_FAMILY
                                    fontPixelSize: UI.FONT_LARGE
                                }
                                font.bold: true
                                color: "#FFFFFF"
                            }
                        }
                    }

                    Image {
                        source:  "image://theme/icon-m-common-drilldown-arrow" + (theme.inverted ? "-inverse" : "")
                        anchors.right: parent.right;
                        anchors.verticalCenter: parent.verticalCenter
                    }

                    MouseArea {
                        id: mouseArea
                        anchors.fill: background
                        onClicked:{
                            if (name === "Settings") {
                                myWindow.updateEdit();
                                rootWindow.loadingSdkToEdit = false;
                                pageStack.push("qrc:/qml_files/EditSettingsScreen.qml");
                            } else if (name === "VNC") {
                                 pageStack.push("qrc:/qml_files/VNCServerScreen.qml");
                            }

                        }
                    }
                }

            } // listview
        } // column

    } // pagecontent column

    } // flickable

    ToolBarLayout {
        id: sdkConnectivityScreenToolbar
        ToolIcon {
            id:toolIconID
            iconId: "toolbar-back";
            onClicked:{
                if(rootWindow.vncSwitchStatus === false) {
                    pageStack.pop();
                    console.log("clicked BACK button")
                    if (pageStack.depth===1) {
                        pageStack.push("qrc:/qml_files/ConnectionScreen.qml");
                    }
                } else {
                    showMessage();
                }
            }
        }
    }
} // page
