import Qt 4.7
import com.nokia.meego 1.0
import com.nokia.extras 1.0

import "UIConstants.js" as UI

Page {
    id:vncServerScreen
    orientationLock: PageOrientation.LockPortrait
    tools: navigationToolbar

    property bool networkConnectionState : (rootWindow.connectionType === "WLAN" && rootWindow.ipValWlan !== "0.0.0.0") ? true : (rootWindow.connectionType === "USB" && rootWindow.usbStatusVal === "Connected")

    Component.onCompleted: {
        vncViewOnlySwitch.checked = myWindow.viewOnly;
        vncSwitch.checked = rootWindow.vncSwitchStatus;
    }

    InfoBanner {
         id: banner
         z:10000
         timerShowTime: 10000

         Connections {
             target: myWindow
             onFileSaved:{

                 banner.text = "File saved at: "+myWindow.fileName
                 banner.show();
             }
         }
     }

    PageTitle {
        id: titleName
        anchors.top: parent.top
        text: "VNC"
    }

    Image {
        id: appIcon
        anchors.top: titleName.top
        anchors.right: titleName.right
        anchors.rightMargin: 10
        anchors.topMargin: 10
        height: titleName.height - 20
        width: height
        z: 20

        source: (rootWindow.connectionType === "USB") ? "image://theme/icon-m-common-usb" : "image://theme/icon-m-common-wlan" //rootWindow.usbImageSource
        smooth: true
        //visible: (rootWindow.connectionType === "USB")
    }

    Column {
        id: pageContent
        spacing: 20
        anchors.margins: UI.HEADER_DEFAULT_TOP_SPACING_PORTRAIT
        anchors.top: titleName.bottom
        anchors.bottom: parent.bottom
        anchors.left: parent.left
        anchors.right: parent.right

        Row {
            id:vncRow
            width: parent.width
            spacing: 20

            Column {
                id: disconnectedStateTip
                spacing: 8
                visible: !networkConnectionState
                Row {
                    width: pageContent.width
                    Label {
                        text: "You can not run VNC server when you are disconnected from network."
                        platformStyle: LabelStyle {
                            fontFamily: UI.FONT_FAMILY_LIGHT
                            fontPixelSize: UI.FONT_DEFAULT
                            textColor: UI.COLOR_INVERTED_SECONDARY_FOREGROUND
                        }
                        width: parent.width
                        wrapMode: Text.WordWrap
                    }
                }
            }
            Label {
                id:vncServerLabel
                text: "Run VNC Server on " + rootWindow.connectionType
                anchors.verticalCenter: parent.verticalCenter
                width: parent.width - parent.spacing - vncSwitch.width
                platformStyle: LabelStyle {
                    fontFamily: UI.FONT_FAMILY
                    fontPixelSize: UI.FONT_SLARGE
                }
                color: "#797979"
            }
            Switch {
                id:vncSwitch
                enabled: networkConnectionState
                checked: rootWindow.vncSwitchStatus //false
                onCheckedChanged: {

                    if(vncSwitch.checked && rootWindow.previousVncStatus === false)
                    {

                        if(rootWindow.connectionType === "USB")
                        {
                            myWindow.vncProcessStart(rootWindow.ipVal,rootWindow.passwordVal,vncViewOnlySwitch.checked)
                        }
                        else
                        {
                            myWindow.vncProcessStart(rootWindow.ipValWlan,rootWindow.passwordVal,vncViewOnlySwitch.checked)
                        }
                    }
                    else if(!vncSwitch.checked)
                    {
                        myWindow.vncProcessStop()
                    }

                    if(vncSwitch.checked)
                    {
                        rootWindow.vncSwitchStatus = true
                        rootWindow.previousVncStatus = true
                        rootWindow.vncTempOutput = vncOutput.text
                    }
                    else
                    {
                        rootWindow.vncSwitchStatus = false
                        rootWindow.vncTempOutput = ""
                        rootWindow.previousVncStatus = false
                    }
                }
            }
        }
        Row {
            id: viewOnlyRow
            spacing: 20
            width: parent.width
            visible: networkConnectionState

            Label {
                text: "VNC Session is view only"
                anchors.verticalCenter: parent.verticalCenter
                width: parent.width - parent.spacing - vncViewOnlySwitch.width
                platformStyle: LabelStyle {
                    fontFamily: UI.FONT_FAMILY
                    fontPixelSize: UI.FONT_LSMALL
                }
                color: "#797979"
            }
            Switch {
                id: vncViewOnlySwitch
                enabled: !vncSwitch.checked && networkConnectionState
                onCheckedChanged: {
                    myWindow.setViewOnly(checked);
                }
            }
        }
        Row {
            id: passwdRow
            spacing: 20
            width: parent.width
            visible: vncSwitch.checked

            Label {
                text: "Password"
                anchors.verticalCenter: parent.verticalCenter
                width: parent.width - parent.spacing - vncPasswdLabel.width
                platformStyle: LabelStyle {
                    fontFamily: UI.FONT_FAMILY
                    fontPixelSize: UI.FONT_LSMALL
                }
                color: "#797979"
            }
            Label {
                id: vncPasswdLabel
                anchors.verticalCenter: parent.verticalCenter
                text: (myWindow.vncPasswd === "") ? rootWindow.passwordVal : myWindow.vncPasswd
                platformStyle: LabelStyle {
                    fontFamily: UI.FONT_FAMILY
                    fontPixelSize: UI.FONT_SLARGE
                }
                font.bold: true
                color: "white"
            }
        }
        Row {
            id: ipAddressRow
            spacing: 20
            width: parent.width
            visible: vncSwitch.checked

            Label {
                text: "IP Address"
                anchors.verticalCenter: parent.verticalCenter
                width: parent.width - parent.spacing - ipAddressLabel.width
                platformStyle: LabelStyle {
                    fontFamily: UI.FONT_FAMILY
                    fontPixelSize: UI.FONT_LSMALL
                }
                color: "#797979"
            }
            Label {
                id: ipAddressLabel
                anchors.verticalCenter: parent.verticalCenter
                text: myWindow.vncIp
                platformStyle: LabelStyle {
                    fontFamily: UI.FONT_FAMILY
                    fontPixelSize: UI.FONT_SLARGE
                }
                font.bold: true
                color: "white"
            }
        }


        /*workaround for textArea START*/
        Rectangle {
            id:vncOutputRect
            radius: 20
            visible: networkConnectionState
            width: parent.width
            height: pageHeight - ipAddressRow.height - viewOnlyRow.height - passwdRow.height - vncRow.height - titleName.height - navigationToolbar.height - saveClearButtonRow.height - parent.spacing*5

            Flickable {
                id: flickable1
                anchors.fill: parent

                contentWidth: vncOutput.paintedWidth
                contentHeight: vncOutput.paintedHeight
                clip: true

                function ensureVisible(r)
                {
                    if (contentX >= r.x)
                        contentX = r.x;
                    else if (contentX+width <= r.x+r.width)
                        contentX = r.x+r.width-width;

                    if (contentY >= r.y)
                        contentY = r.y;
                    else if (contentY+height <= r.y+r.height)
                    {
                        contentY = r.y+r.height-height;
                    }

                }

                TextEdit {
                    id: vncOutput
                    width: flickable1.width
                    height: flickable1.height
                    text: rootWindow.vncTempOutput
                    cursorVisible: false
                    readOnly: true
                    font.pixelSize: 16
                    focus: false
                    anchors.leftMargin: 30
                    wrapMode: TextEdit.NoWrap
                    onCursorRectangleChanged: flickable1.ensureVisible(vncOutput.cursorRectangle)

                    Connections {
                        target: vncProcess
                        onLogDataChanged:{

                            vncOutput.text += vncProcess.logData;
                            vncOutput.cursorPosition = vncOutput.text.length;


                        }
                    }

                }

            }
        }

        Row {
            id:saveClearButtonRow
            width: parent.width
            spacing: 20
            visible: networkConnectionState

            Button {
                id:saveButton
                text: "Save log"
                width:implicitWidth/2
                enabled: vncOutput.text == ""? false : true
                onClicked: {
                    myWindow.vncSaveToFile(vncOutput.text);
                }
            }
            Label {
                id: buttonRowSpacer
                width: parent.width - saveButton.width - clearButton.width - parent.spacing - UI.HEADER_DEFAULT_TOP_SPACING_PORTRAIT
            }

            Button {
                id:clearButton
                text: "Clear log"
                width:implicitWidth/2
                enabled:vncOutput.text == "" ? false : true
                onClicked: {
                    vncOutput.text = ""
                }
            }

        }
    }
}
